@@ -3,7 +3,7 @@ from tracardi_plugin_sdk.service.plugin_runner import run_plugin
 
 init = {
             "source": {
-                "id": "74246646-f25e-4592-aea8-3fc383bc461a"
+                "id": "a4fb18a2-5406-4190-bd91-e1719bb5202c"
             },
             "queue": {
                 "name": "tracardi-1",
